@@ -1,20 +1,8 @@
-/*************************************************************************************
- *  Copyright 2014-2015 Sebastian Kügler <sebas@kde.org>                             *
- *                                                                                   *
- *  This library is free software; you can redistribute it and/or                    *
- *  modify it under the terms of the GNU Lesser General Public                       *
- *  License as published by the Free Software Foundation; either                     *
- *  version 2.1 of the License, or (at your option) any later version.               *
- *                                                                                   *
- *  This library is distributed in the hope that it will be useful,                  *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
- *  Lesser General Public License for more details.                                  *
- *                                                                                   *
- *  You should have received a copy of the GNU Lesser General Public                 *
- *  License along with this library; if not, write to the Free Software              *
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
- *************************************************************************************/
+/*
+ *  SPDX-FileCopyrightText: 2014-2015 Sebastian Kügler <sebas@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.1-or-later
+ */
 
 #include "waylandtestserver.h"
 
@@ -78,9 +66,7 @@ void WaylandTestServer::start()
 
 void WaylandTestServer::stop()
 {
-    Q_FOREACH (const auto &o, m_outputs) {
-        delete o;
-    }
+    qDeleteAll(m_outputs);
     m_outputs.clear();
     // actually stop the Wayland server
     delete m_display;
@@ -165,7 +151,7 @@ void WaylandTestServer::configurationChangeRequested(KWayland::Server::OutputCon
 void WaylandTestServer::showOutputs()
 {
     qCDebug(KSCREEN_WAYLAND_TESTSERVER) << "******** Wayland server running: " << m_outputs.count() << " outputs. ********";
-    foreach (auto o, m_outputs) {
+    for (const auto &o : qAsConst(m_outputs)) {
         bool enabled = (o->enabled() == KWayland::Server::OutputDeviceInterface::Enablement::Enabled);
         qCDebug(KSCREEN_WAYLAND_TESTSERVER) << "  * Output id: " << o->uuid();
         qCDebug(KSCREEN_WAYLAND_TESTSERVER) << "      Enabled: " << (enabled ? "enabled" : "disabled");
@@ -183,7 +169,7 @@ QString WaylandTestServer::modeString(KWayland::Server::OutputDeviceInterface *o
     QString s;
     QString ids;
     int _i = 0;
-    Q_FOREACH (const auto &_m, outputdevice->modes()) {
+    for (const auto &_m : outputdevice->modes()) {
         _i++;
         if (_i < 6) {
             ids.append(QString::number(_m.id) + QLatin1String(", "));
